Package: calcite
Title: Bindings to the Calcite Design System 'JavaScript' Component
        Library
Version: 1.0.0
Authors@R: 
    person("Josiah", "Parry", , "josiah.parry@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-9910-865X"))
Description: Provides access to the 'Calcite Design System' 'javascript'
    components via integration with the 'htmltools' and 'shiny' packages.
    Pre-built and interactive components can be used to generate either
    static html or interactive web applications. Learn more about the
    'Calcite Design System' at
    <https://developers.arcgis.com/calcite-design-system/>.
License: Apache License (>= 2)
Imports: cli, htmltools, rlang, shiny, utils, yyjsonr
Suggests: brio, rstudioapi
URL: https://r.esri.com/calcite/
Encoding: UTF-8
Language: en
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-03-02 19:57:28 UTC; josiahparry
Author: Josiah Parry [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9910-865X>)
Maintainer: Josiah Parry <josiah.parry@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-03 10:00:20 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 11:58:04 UTC; unix
Archs: calcite.so.dSYM
